@@ -12,11 +12,17 @@ set -e
 CHROOT_DIR=/tmp/chroot
 
 # Debian package dependencies for the host to run ARM under QEMU
-DEBIAN_MIRROR="http://ftp.us.debian.org/debian"
+DEBIAN_MIRROR="http://httpredir.debian.org/debian"
 HOST_DEPENDENCIES="qemu-user-static binfmt-support debootstrap sbuild wget"
 
 # Debian package dependencies for the chrooted environment
-GUEST_DEPENDENCIES="build-essential libcurl4-openssl-dev libsqlite3-dev libgnutls-openssl27 git"
+GUEST_DEPENDENCIES="build-essential libcurl4-openssl-dev libsqlite3-dev libgnutls-openssl27 git pkg-config libxml2"
+
+# LDC Version
+# Different versions due to https://github.com/ldc-developers/ldc/issues/3027
+# LDC v1.16.0 re-introduces ARMHF and ARM64 version - https://github.com/ldc-developers/ldc/releases/tag/v1.16.0
+LDC_VERSION_ARMHF=1.16.0
+LDC_VERSION_ARM64=1.16.0
 
 function setup_arm32_chroot {
 	# Update apt repository details
@@ -27,10 +33,10 @@ function setup_arm32_chroot {
 	# Host dependencies
 	sudo apt-get install -qq -y ${HOST_DEPENDENCIES}
 	# Download LDC compiler
-	wget https://github.com/ldc-developers/ldc/releases/download/v1.11.0/ldc2-1.11.0-linux-armhf.tar.xz
-	tar -xf ldc2-1.11.0-linux-armhf.tar.xz
-	mv ldc2-1.11.0-linux-armhf dlang-${ARCH}
-	rm -rf ldc2-1.11.0-linux-armhf.tar.xz
+	wget https://github.com/ldc-developers/ldc/releases/download/v${LDC_VERSION_ARMHF}/ldc2-${LDC_VERSION_ARMHF}-linux-armhf.tar.xz
+	tar -xf ldc2-${LDC_VERSION_ARMHF}-linux-armhf.tar.xz
+	mv ldc2-${LDC_VERSION_ARMHF}-linux-armhf dlang-${ARCH}
+	rm -rf ldc2-${LDC_VERSION_ARMHF}-linux-armhf.tar.xz
 	# Create chrooted environment
 	sudo mkdir ${CHROOT_DIR}
 	sudo debootstrap --foreign --no-check-gpg --variant=buildd --arch=${CHROOT_ARCH} ${VERSION} ${CHROOT_DIR} ${DEBIAN_MIRROR}
@@ -49,10 +55,10 @@ function setup_arm64_chroot {
 	# Host dependencies
 	sudo apt-get install -qq -y ${HOST_DEPENDENCIES}
 	# Download LDC compiler
-	wget https://github.com/ldc-developers/ldc/releases/download/v1.11.0/ldc2-1.11.0-linux-aarch64.tar.xz
-	tar -xf ldc2-1.11.0-linux-aarch64.tar.xz
-	mv ldc2-1.11.0-linux-aarch64 dlang-${ARCH}
-	rm -rf ldc2-1.11.0-linux-aarch64.tar.xz
+	wget https://github.com/ldc-developers/ldc/releases/download/v${LDC_VERSION_ARM64}/ldc2-${LDC_VERSION_ARM64}-linux-aarch64.tar.xz
+	tar -xf ldc2-${LDC_VERSION_ARM64}-linux-aarch64.tar.xz
+	mv ldc2-${LDC_VERSION_ARM64}-linux-aarch64 dlang-${ARCH}
+	rm -rf ldc2-${LDC_VERSION_ARM64}-linux-aarch64.tar.xz
 	
 	# ARM64 qemu-debootstrap needs to be 1.0.78, Trusty is 1.0.59
 	#sudo echo "deb http://archive.ubuntu.com/ubuntu xenial main restricted universe multiverse" >> /etc/apt/sources.list
@@ -75,10 +81,11 @@ function setup_x32_chroot {
 	# Host dependencies
 	sudo apt-get install -qq -y ${HOST_DEPENDENCIES}
 	# Download DMD compiler
-	wget http://downloads.dlang.org/releases/2.x/2.081.1/dmd.2.081.1.linux.tar.xz
-	tar -xf dmd.2.081.1.linux.tar.xz
+	DMDVER=2.083.1
+	wget http://downloads.dlang.org/releases/2.x/${DMDVER}/dmd.${DMDVER}.linux.tar.xz
+	tar -xf dmd.${DMDVER}.linux.tar.xz
 	mv dmd2 dlang-${ARCH}
-	rm -rf dmd.2.081.1.linux.tar.xz
+	rm -rf dmd.${DMDVER}.linux.tar.xz
 	# Create chrooted environment
 	sudo mkdir ${CHROOT_DIR}
 	sudo debootstrap --foreign --no-check-gpg --variant=buildd --arch=${CHROOT_ARCH32} ${VERSION} ${CHROOT_DIR} ${DEBIAN_MIRROR}
@@ -117,16 +124,19 @@ function build_onedrive {
 	HOMEDIR=$(pwd)
 	if [ "${ARCH}" = "x64" ]; then
 		# Build on x86_64 as normal
+		./configure
 		make clean; make;
 	else
 		if [ "${ARCH}" = "x32" ]; then
 			# 32Bit DMD Build
+			./configure DC=${HOMEDIR}/dlang-${ARCH}/linux/bin32/dmd
 			make clean;
-			make DC=${HOMEDIR}/dlang-${ARCH}/linux/bin32/dmd
+			make
 		else
 			# LDC Build - ARM32, ARM64
+			./configure DC=${HOMEDIR}/dlang-${ARCH}/bin/ldmd2
 			make clean;
-			make DC=${HOMEDIR}/dlang-${ARCH}/bin/ldmd2
+			make
 		fi
 	fi
 	# Functional testing of built application
